from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.column_default_checks_pattern_spec import (
        ColumnDefaultChecksPatternSpec,
    )


T = TypeVar("T", bound="DefaultColumnChecksPatternModel")


@_attrs_define
class DefaultColumnChecksPatternModel:
    """Default column-level checks pattern model

    Attributes:
        pattern_name (Union[Unset, str]): Pattern name
        pattern_spec (Union[Unset, ColumnDefaultChecksPatternSpec]):
        can_edit (Union[Unset, bool]): Boolean flag that decides if the current user can update or delete this object.
        yaml_parsing_error (Union[Unset, str]): Optional parsing error that was captured when parsing the YAML file.
            This field is null when the YAML file is valid. If an error was captured, this field returns the file parsing
            error message and the file location.
    """

    pattern_name: Union[Unset, str] = UNSET
    pattern_spec: Union[Unset, "ColumnDefaultChecksPatternSpec"] = UNSET
    can_edit: Union[Unset, bool] = UNSET
    yaml_parsing_error: Union[Unset, str] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        pattern_name = self.pattern_name
        pattern_spec: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.pattern_spec, Unset):
            pattern_spec = self.pattern_spec.to_dict()

        can_edit = self.can_edit
        yaml_parsing_error = self.yaml_parsing_error

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if pattern_name is not UNSET:
            field_dict["pattern_name"] = pattern_name
        if pattern_spec is not UNSET:
            field_dict["pattern_spec"] = pattern_spec
        if can_edit is not UNSET:
            field_dict["can_edit"] = can_edit
        if yaml_parsing_error is not UNSET:
            field_dict["yaml_parsing_error"] = yaml_parsing_error

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.column_default_checks_pattern_spec import (
            ColumnDefaultChecksPatternSpec,
        )

        d = src_dict.copy()
        pattern_name = d.pop("pattern_name", UNSET)

        _pattern_spec = d.pop("pattern_spec", UNSET)
        pattern_spec: Union[Unset, ColumnDefaultChecksPatternSpec]
        if isinstance(_pattern_spec, Unset):
            pattern_spec = UNSET
        else:
            pattern_spec = ColumnDefaultChecksPatternSpec.from_dict(_pattern_spec)

        can_edit = d.pop("can_edit", UNSET)

        yaml_parsing_error = d.pop("yaml_parsing_error", UNSET)

        default_column_checks_pattern_model = cls(
            pattern_name=pattern_name,
            pattern_spec=pattern_spec,
            can_edit=can_edit,
            yaml_parsing_error=yaml_parsing_error,
        )

        default_column_checks_pattern_model.additional_properties = d
        return default_column_checks_pattern_model

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.column_conversions_daily_partitioned_checks_spec_custom_checks import (
        ColumnConversionsDailyPartitionedChecksSpecCustomChecks,
    )
    from ..models.column_text_parsable_to_boolean_percent_check_spec import (
        ColumnTextParsableToBooleanPercentCheckSpec,
    )
    from ..models.column_text_parsable_to_date_percent_check_spec import (
        ColumnTextParsableToDatePercentCheckSpec,
    )
    from ..models.column_text_parsable_to_float_percent_check_spec import (
        ColumnTextParsableToFloatPercentCheckSpec,
    )
    from ..models.column_text_parsable_to_integer_percent_check_spec import (
        ColumnTextParsableToIntegerPercentCheckSpec,
    )


T = TypeVar("T", bound="ColumnConversionsDailyPartitionedChecksSpec")


@_attrs_define
class ColumnConversionsDailyPartitionedChecksSpec:
    """
    Attributes:
        custom_checks (Union[Unset, ColumnConversionsDailyPartitionedChecksSpecCustomChecks]): Dictionary of additional
            custom checks within this category. The keys are check names defined in the definition section. The sensor
            parameters and rules should match the type of the configured sensor and rule for the custom check.
        daily_partition_text_parsable_to_boolean_percent (Union[Unset, ColumnTextParsableToBooleanPercentCheckSpec]):
        daily_partition_text_parsable_to_integer_percent (Union[Unset, ColumnTextParsableToIntegerPercentCheckSpec]):
        daily_partition_text_parsable_to_float_percent (Union[Unset, ColumnTextParsableToFloatPercentCheckSpec]):
        daily_partition_text_parsable_to_date_percent (Union[Unset, ColumnTextParsableToDatePercentCheckSpec]):
    """

    custom_checks: Union[
        Unset, "ColumnConversionsDailyPartitionedChecksSpecCustomChecks"
    ] = UNSET
    daily_partition_text_parsable_to_boolean_percent: Union[
        Unset, "ColumnTextParsableToBooleanPercentCheckSpec"
    ] = UNSET
    daily_partition_text_parsable_to_integer_percent: Union[
        Unset, "ColumnTextParsableToIntegerPercentCheckSpec"
    ] = UNSET
    daily_partition_text_parsable_to_float_percent: Union[
        Unset, "ColumnTextParsableToFloatPercentCheckSpec"
    ] = UNSET
    daily_partition_text_parsable_to_date_percent: Union[
        Unset, "ColumnTextParsableToDatePercentCheckSpec"
    ] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        custom_checks: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.custom_checks, Unset):
            custom_checks = self.custom_checks.to_dict()

        daily_partition_text_parsable_to_boolean_percent: Union[
            Unset, Dict[str, Any]
        ] = UNSET
        if not isinstance(self.daily_partition_text_parsable_to_boolean_percent, Unset):
            daily_partition_text_parsable_to_boolean_percent = (
                self.daily_partition_text_parsable_to_boolean_percent.to_dict()
            )

        daily_partition_text_parsable_to_integer_percent: Union[
            Unset, Dict[str, Any]
        ] = UNSET
        if not isinstance(self.daily_partition_text_parsable_to_integer_percent, Unset):
            daily_partition_text_parsable_to_integer_percent = (
                self.daily_partition_text_parsable_to_integer_percent.to_dict()
            )

        daily_partition_text_parsable_to_float_percent: Union[
            Unset, Dict[str, Any]
        ] = UNSET
        if not isinstance(self.daily_partition_text_parsable_to_float_percent, Unset):
            daily_partition_text_parsable_to_float_percent = (
                self.daily_partition_text_parsable_to_float_percent.to_dict()
            )

        daily_partition_text_parsable_to_date_percent: Union[
            Unset, Dict[str, Any]
        ] = UNSET
        if not isinstance(self.daily_partition_text_parsable_to_date_percent, Unset):
            daily_partition_text_parsable_to_date_percent = (
                self.daily_partition_text_parsable_to_date_percent.to_dict()
            )

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if custom_checks is not UNSET:
            field_dict["custom_checks"] = custom_checks
        if daily_partition_text_parsable_to_boolean_percent is not UNSET:
            field_dict[
                "daily_partition_text_parsable_to_boolean_percent"
            ] = daily_partition_text_parsable_to_boolean_percent
        if daily_partition_text_parsable_to_integer_percent is not UNSET:
            field_dict[
                "daily_partition_text_parsable_to_integer_percent"
            ] = daily_partition_text_parsable_to_integer_percent
        if daily_partition_text_parsable_to_float_percent is not UNSET:
            field_dict[
                "daily_partition_text_parsable_to_float_percent"
            ] = daily_partition_text_parsable_to_float_percent
        if daily_partition_text_parsable_to_date_percent is not UNSET:
            field_dict[
                "daily_partition_text_parsable_to_date_percent"
            ] = daily_partition_text_parsable_to_date_percent

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.column_conversions_daily_partitioned_checks_spec_custom_checks import (
            ColumnConversionsDailyPartitionedChecksSpecCustomChecks,
        )
        from ..models.column_text_parsable_to_boolean_percent_check_spec import (
            ColumnTextParsableToBooleanPercentCheckSpec,
        )
        from ..models.column_text_parsable_to_date_percent_check_spec import (
            ColumnTextParsableToDatePercentCheckSpec,
        )
        from ..models.column_text_parsable_to_float_percent_check_spec import (
            ColumnTextParsableToFloatPercentCheckSpec,
        )
        from ..models.column_text_parsable_to_integer_percent_check_spec import (
            ColumnTextParsableToIntegerPercentCheckSpec,
        )

        d = src_dict.copy()
        _custom_checks = d.pop("custom_checks", UNSET)
        custom_checks: Union[
            Unset, ColumnConversionsDailyPartitionedChecksSpecCustomChecks
        ]
        if isinstance(_custom_checks, Unset):
            custom_checks = UNSET
        else:
            custom_checks = (
                ColumnConversionsDailyPartitionedChecksSpecCustomChecks.from_dict(
                    _custom_checks
                )
            )

        _daily_partition_text_parsable_to_boolean_percent = d.pop(
            "daily_partition_text_parsable_to_boolean_percent", UNSET
        )
        daily_partition_text_parsable_to_boolean_percent: Union[
            Unset, ColumnTextParsableToBooleanPercentCheckSpec
        ]
        if isinstance(_daily_partition_text_parsable_to_boolean_percent, Unset):
            daily_partition_text_parsable_to_boolean_percent = UNSET
        else:
            daily_partition_text_parsable_to_boolean_percent = (
                ColumnTextParsableToBooleanPercentCheckSpec.from_dict(
                    _daily_partition_text_parsable_to_boolean_percent
                )
            )

        _daily_partition_text_parsable_to_integer_percent = d.pop(
            "daily_partition_text_parsable_to_integer_percent", UNSET
        )
        daily_partition_text_parsable_to_integer_percent: Union[
            Unset, ColumnTextParsableToIntegerPercentCheckSpec
        ]
        if isinstance(_daily_partition_text_parsable_to_integer_percent, Unset):
            daily_partition_text_parsable_to_integer_percent = UNSET
        else:
            daily_partition_text_parsable_to_integer_percent = (
                ColumnTextParsableToIntegerPercentCheckSpec.from_dict(
                    _daily_partition_text_parsable_to_integer_percent
                )
            )

        _daily_partition_text_parsable_to_float_percent = d.pop(
            "daily_partition_text_parsable_to_float_percent", UNSET
        )
        daily_partition_text_parsable_to_float_percent: Union[
            Unset, ColumnTextParsableToFloatPercentCheckSpec
        ]
        if isinstance(_daily_partition_text_parsable_to_float_percent, Unset):
            daily_partition_text_parsable_to_float_percent = UNSET
        else:
            daily_partition_text_parsable_to_float_percent = (
                ColumnTextParsableToFloatPercentCheckSpec.from_dict(
                    _daily_partition_text_parsable_to_float_percent
                )
            )

        _daily_partition_text_parsable_to_date_percent = d.pop(
            "daily_partition_text_parsable_to_date_percent", UNSET
        )
        daily_partition_text_parsable_to_date_percent: Union[
            Unset, ColumnTextParsableToDatePercentCheckSpec
        ]
        if isinstance(_daily_partition_text_parsable_to_date_percent, Unset):
            daily_partition_text_parsable_to_date_percent = UNSET
        else:
            daily_partition_text_parsable_to_date_percent = (
                ColumnTextParsableToDatePercentCheckSpec.from_dict(
                    _daily_partition_text_parsable_to_date_percent
                )
            )

        column_conversions_daily_partitioned_checks_spec = cls(
            custom_checks=custom_checks,
            daily_partition_text_parsable_to_boolean_percent=daily_partition_text_parsable_to_boolean_percent,
            daily_partition_text_parsable_to_integer_percent=daily_partition_text_parsable_to_integer_percent,
            daily_partition_text_parsable_to_float_percent=daily_partition_text_parsable_to_float_percent,
            daily_partition_text_parsable_to_date_percent=daily_partition_text_parsable_to_date_percent,
        )

        column_conversions_daily_partitioned_checks_spec.additional_properties = d
        return column_conversions_daily_partitioned_checks_spec

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from http import HTTPStatus
from typing import Any, Dict, Optional, Union, cast

import httpx

from ... import errors
from ...client import AuthenticatedClient, Client
from ...types import Response


def _get_kwargs() -> Dict[str, Any]:
    pass

    return {
        "method": "get",
        "url": "api/ishealthy",
    }


def _parse_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Optional[str]:
    if response.status_code == HTTPStatus.OK:
        response_200 = cast(str, response.json())
        return response_200
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Response[str]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    *,
    client: Union[AuthenticatedClient, Client],
) -> Response[str]:
    r"""isHealthy

     Checks if the DQOps instance is healthy and operational. Returns a text \"OK\" and a HTTP status
    code 200 when the service is active and can accept jobs,  or returns a text \"UNAVAILABLE\" and a
    HTTP status code 503 when the service is still starting or is shutting down.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[str]
    """

    kwargs = _get_kwargs()

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    *,
    client: Union[AuthenticatedClient, Client],
) -> Optional[str]:
    r"""isHealthy

     Checks if the DQOps instance is healthy and operational. Returns a text \"OK\" and a HTTP status
    code 200 when the service is active and can accept jobs,  or returns a text \"UNAVAILABLE\" and a
    HTTP status code 503 when the service is still starting or is shutting down.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        str
    """

    return sync_detailed(
        client=client,
    ).parsed


async def asyncio_detailed(
    *,
    client: Union[AuthenticatedClient, Client],
) -> Response[str]:
    r"""isHealthy

     Checks if the DQOps instance is healthy and operational. Returns a text \"OK\" and a HTTP status
    code 200 when the service is active and can accept jobs,  or returns a text \"UNAVAILABLE\" and a
    HTTP status code 503 when the service is still starting or is shutting down.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[str]
    """

    kwargs = _get_kwargs()

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    *,
    client: Union[AuthenticatedClient, Client],
) -> Optional[str]:
    r"""isHealthy

     Checks if the DQOps instance is healthy and operational. Returns a text \"OK\" and a HTTP status
    code 200 when the service is active and can accept jobs,  or returns a text \"UNAVAILABLE\" and a
    HTTP status code 503 when the service is still starting or is shutting down.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        str
    """

    return (
        await asyncio_detailed(
            client=client,
        )
    ).parsed



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field

if TYPE_CHECKING:
    from ..models.column_current_data_quality_status_model import (
        ColumnCurrentDataQualityStatusModel,
    )


T = TypeVar("T", bound="TableCurrentDataQualityStatusModelColumns")


@_attrs_define
class TableCurrentDataQualityStatusModelColumns:
    """Dictionary of data statues for all columns that have any known data quality results. The keys in the dictionary are
    the column names.

    """

    additional_properties: Dict[
        str, "ColumnCurrentDataQualityStatusModel"
    ] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        pass

        field_dict: Dict[str, Any] = {}
        for prop_name, prop in self.additional_properties.items():
            field_dict[prop_name] = prop.to_dict()

        field_dict.update({})

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.column_current_data_quality_status_model import (
            ColumnCurrentDataQualityStatusModel,
        )

        d = src_dict.copy()
        table_current_data_quality_status_model_columns = cls()

        additional_properties = {}
        for prop_name, prop_dict in d.items():
            additional_property = ColumnCurrentDataQualityStatusModel.from_dict(
                prop_dict
            )

            additional_properties[prop_name] = additional_property

        table_current_data_quality_status_model_columns.additional_properties = (
            additional_properties
        )
        return table_current_data_quality_status_model_columns

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> "ColumnCurrentDataQualityStatusModel":
        return self.additional_properties[key]

    def __setitem__(
        self, key: str, value: "ColumnCurrentDataQualityStatusModel"
    ) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.target_table_pattern_spec import TargetTablePatternSpec


T = TypeVar("T", bound="DefaultTableChecksPatternListModel")


@_attrs_define
class DefaultTableChecksPatternListModel:
    """Default table-level checks pattern list model

    Attributes:
        pattern_name (Union[Unset, str]): Pattern name.
        priority (Union[Unset, int]): The priority of the pattern. Patterns with lower values are applied before
            patterns with higher priority values.
        target_table (Union[Unset, TargetTablePatternSpec]):
        can_edit (Union[Unset, bool]): Boolean flag that decides if the current user can update or delete this object.
        yaml_parsing_error (Union[Unset, str]): Optional parsing error that was captured when parsing the YAML file.
            This field is null when the YAML file is valid. If an error was captured, this field returns the file parsing
            error message and the file location.
    """

    pattern_name: Union[Unset, str] = UNSET
    priority: Union[Unset, int] = UNSET
    target_table: Union[Unset, "TargetTablePatternSpec"] = UNSET
    can_edit: Union[Unset, bool] = UNSET
    yaml_parsing_error: Union[Unset, str] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        pattern_name = self.pattern_name
        priority = self.priority
        target_table: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.target_table, Unset):
            target_table = self.target_table.to_dict()

        can_edit = self.can_edit
        yaml_parsing_error = self.yaml_parsing_error

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if pattern_name is not UNSET:
            field_dict["pattern_name"] = pattern_name
        if priority is not UNSET:
            field_dict["priority"] = priority
        if target_table is not UNSET:
            field_dict["target_table"] = target_table
        if can_edit is not UNSET:
            field_dict["can_edit"] = can_edit
        if yaml_parsing_error is not UNSET:
            field_dict["yaml_parsing_error"] = yaml_parsing_error

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.target_table_pattern_spec import TargetTablePatternSpec

        d = src_dict.copy()
        pattern_name = d.pop("pattern_name", UNSET)

        priority = d.pop("priority", UNSET)

        _target_table = d.pop("target_table", UNSET)
        target_table: Union[Unset, TargetTablePatternSpec]
        if isinstance(_target_table, Unset):
            target_table = UNSET
        else:
            target_table = TargetTablePatternSpec.from_dict(_target_table)

        can_edit = d.pop("can_edit", UNSET)

        yaml_parsing_error = d.pop("yaml_parsing_error", UNSET)

        default_table_checks_pattern_list_model = cls(
            pattern_name=pattern_name,
            priority=priority,
            target_table=target_table,
            can_edit=can_edit,
            yaml_parsing_error=yaml_parsing_error,
        )

        default_table_checks_pattern_list_model.additional_properties = d
        return default_table_checks_pattern_list_model

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.hierarchy_id_model_path_item import HierarchyIdModelPathItem


T = TypeVar("T", bound="HierarchyIdModel")


@_attrs_define
class HierarchyIdModel:
    """
    Attributes:
        path (Union[Unset, List['HierarchyIdModelPathItem']]):
    """

    path: Union[Unset, List["HierarchyIdModelPathItem"]] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        path: Union[Unset, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.path, Unset):
            path = []
            for path_item_data in self.path:
                path_item = path_item_data.to_dict()

                path.append(path_item)

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if path is not UNSET:
            field_dict["path"] = path

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.hierarchy_id_model_path_item import HierarchyIdModelPathItem

        d = src_dict.copy()
        path = []
        _path = d.pop("path", UNSET)
        for path_item_data in _path or []:
            path_item = HierarchyIdModelPathItem.from_dict(path_item_data)

            path.append(path_item)

        hierarchy_id_model = cls(
            path=path,
        )

        hierarchy_id_model.additional_properties = d
        return hierarchy_id_model

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

T = TypeVar(
    "T", bound="AnomalyStationaryPercentileMovingAverageRuleWarning1PctParametersSpec"
)


@_attrs_define
class AnomalyStationaryPercentileMovingAverageRuleWarning1PctParametersSpec:
    """
    Attributes:
        anomaly_percent (Union[Unset, float]): The probability (in percent) that the current sensor readout (measure) is
            an anomaly, because the value is outside the regular range of previous readouts. The default time window of 90
            time periods (days, etc.) is used, but at least 30 readouts must exist to run the calculation.
    """

    anomaly_percent: Union[Unset, float] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        anomaly_percent = self.anomaly_percent

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if anomaly_percent is not UNSET:
            field_dict["anomaly_percent"] = anomaly_percent

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        anomaly_percent = d.pop("anomaly_percent", UNSET)

        anomaly_stationary_percentile_moving_average_rule_warning_1_pct_parameters_spec = cls(
            anomaly_percent=anomaly_percent,
        )

        anomaly_stationary_percentile_moving_average_rule_warning_1_pct_parameters_spec.additional_properties = (
            d
        )
        return anomaly_stationary_percentile_moving_average_rule_warning_1_pct_parameters_spec

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
